﻿using System;
using System.Collections.Generic;
using System.Data;
using System.Data.Entity;
using System.Linq;
using System.Web;
using System.Web.Mvc;
using CodeCamp_2011_ProSkills_Project.Models;
using CodeCamp_2011_ProSkills_Project.Models.Dal;
using System.IO;
using System.ComponentModel;


namespace CodeCamp_2011_ProSkills_Project.Controllers
{ 
    public class CourseController : Controller
    {
        private SkillContext db = new SkillContext();

        //
        // GET: /Course/

        public ViewResult Index()
        {
            return View(db.Courses.ToList());
        }

        //
        // GET: /Course/Details/5

        public ViewResult Details(int id)
        {
            ViewData["CourseStudents"] = new SelectList(new List<CourseEnrollment>());
            ViewData["Course"] = new CourseEnrollment();
            Course course = db.Courses.Find(id);
            List<CourseEnrollment> enrollments =
                (from ce in db.CourseEnrollment
                 where ce.Course.id == id 
                 && ce.User.userName == User.Identity.Name
                 select ce).ToList();
            //Simo on fag
            List<FileUpload> files =
                (from file in db.Files
                 where file.course.id == id
                 select file).ToList();
            course.files = files;
            ViewBag.Enrolled = enrollments.Count > 0;
            ViewBag.CourseId = id;
            return View(course);
        }

        public ActionResult Enroll(int id)
        {
            Course course = db.Courses.Find(id);
            User user =
                   (from u in db.Users
                    where u.userName == User.Identity.Name
                    select u).SingleOrDefault();
            if (user != null)
            {
                CourseEnrollment enrollment = new CourseEnrollment();
                enrollment.User = user;
                enrollment.Course = course;
                course.courseEnrollments.Add(enrollment);
                db.CourseEnrollment.Add(enrollment);
                db.SaveChanges();
            }
            return RedirectToAction("Details", new { id = id });
        }

        //
        // GET: /Course/Create

        public ActionResult Create()
        {
            return View();
        } 

        //
        // POST: /Course/Create

        [HttpPost]
        public ActionResult Create(Course course)
        {
            if (ModelState.IsValid)
            {
                db.Courses.Add(course);
                db.SaveChanges();
                return RedirectToAction("Index");  
            }

            return View(course);
        }
        
        //
        // GET: /Course/Edit/5
 
        public ActionResult Edit(int id)
        {
            Course course = db.Courses.Find(id);
            return View(course);
        }

        //
        // POST: /Course/Edit/5

        [HttpPost]
        public ActionResult Edit(Course course)
        {
            if (ModelState.IsValid)
            {
                db.Entry(course).State = EntityState.Modified;
                db.SaveChanges();
                return RedirectToAction("Index");
            }
            return View(course);
        }

        //
        // GET: /Course/Delete/5
 
        public ActionResult Delete(int id)
        {
            Course course = db.Courses.Find(id);
            return View(course);
        }

        //
        // POST: /Course/Delete/5

        [HttpPost, ActionName("Delete")]
        public ActionResult DeleteConfirmed(int id)
        {            
            Course course = db.Courses.Find(id);
            db.Courses.Remove(course);
            db.SaveChanges();
            return RedirectToAction("Index");
        }

        protected override void Dispose(bool disposing)
        {
            db.Dispose();
            base.Dispose(disposing);
        }

        [HttpGet]
        public PartialViewResult Attachment(int courseId)
        {
            ViewBag.CourseId = courseId;
            return PartialView();
        }

        [HttpPost]
        public ActionResult Uploadfile(HttpPostedFileBase theFile, int courseId)
        {
            if (theFile.ContentLength > 0)
            {

                Course course = db.Courses.Find(courseId);
                theFile.SaveAs(Path.Combine(Server.MapPath("~/App_Data/Uploads/"), theFile.FileName));
                FileUpload file = new FileUpload();
                file.course = course;
                file.fileName = theFile.FileName;
                file.filePath = Path.Combine(Server.MapPath("~/App_Data/Uploads/"), theFile.FileName);
                file.fileType = theFile.ContentType;
                course.files.Add(file);
                db.Files.Add(file);
                db.SaveChanges();
            }
            return RedirectToAction("Details", new { id = courseId });
        }

        public FileResult LoadFile(int id)
        {
            FileUpload fileUpload = db.Files.Find(id);
            FileStream file = new FileStream(fileUpload.filePath, FileMode.Open);
            var cd = new System.Net.Mime.ContentDisposition
            {
                FileName = fileUpload.fileName,
                
                Inline = false,
            };

            Response.AppendHeader("Content-Disposition", cd.ToString());
            return new FileStreamResult(file, fileUpload.fileType);
        }

        [HttpGet]
        public ActionResult AddGrade(int id)
        {
            List<CourseEnrollment> CourseStudents =
                (from c in db.CourseEnrollment
                 where c.Course.id == id && c.Grade == 0
                 select c).ToList();

            if (CourseStudents != null)
            {
                ViewData["CourseStudents"] = new SelectList(CourseStudents, "Course", "id");
            }
            else
            {
               
                ViewData["CourseStudents"] = new SelectList(new List<CourseEnrollment>());
                ViewData["CourseStudent"] = new CourseEnrollment();
            }
            
            String s = " ";
            ViewData["Grade"] = s.ToString();
            return PartialView("_ShowGrades");
        }

        [HttpPost]
        public void saveGrade(int grade, CourseEnrollment courseEnrollment)
        {
            if (courseEnrollment != null)
            {
                courseEnrollment.Grade = grade;
                db.SaveChanges();
            }
        }

    }
}